@@ -19,6 +19,7 @@
 #ifndef UBUNTU_TEST_UBUNTUTESTCASE_H
 #define UBUNTU_TEST_UBUNTUTESTCASE_H
 
+#include <QtTest/QtTest>
 #include <QtQuick/QQuickItem>
 #include <QtQuick/QQuickView>
 #include <QtTest/QSignalSpy>
@@ -29,6 +30,7 @@ class UbuntuTestCase : public QQuickView
 
 public:
     UbuntuTestCase(const QString& file, QWindow* parent = 0);
+    int warnings() const;
     // getter
     template<class T>
     inline T findItem(const QString& objectName) const {
@@ -40,6 +42,20 @@ public:
         qFatal("No item '%s' found", qPrintable(objectName));
     }
 
+    static inline QPointF centerOf(QQuickItem *item, bool windowPos = false)
+    {
+        QPointF center;
+        if (item) {
+            center = item->boundingRect().center();
+            if (windowPos) {
+                center = item->mapToScene(center);
+            }
+        }
+        return center;
+    }
+
+    static void ignoreWarning(const QString& fileName, uint line, uint column, const QString& message, uint occurences=1);
+
 private:
     QSignalSpy* m_spy;
 };
